@@ -102,6 +102,21 @@
  * Default: true */
 #define VOIKKO_OPT_IGNORE_NONWORDS 10
 
+/* (Spell checking only): Allow some extra hyphens in words. This option relaxes
+ * hyphen checking rules to work around some unresolved issues in the underlying
+ * morphology, but it may cause some incorrect words to be accepted. The exact
+ * behaviour (if any) of this option is not specified.
+ * Default: false */
+#define VOIKKO_OPT_ACCEPT_EXTRA_HYPHENS 11
+
+/* (Spell checking only): Accept missing hyphens at the start and end of the word.
+ * Some application programs do not consider hyphens to be word characters. This
+ * is reasonable assumption for many languages but not for Finnish. If the
+ * application cannot be fixed to use proper tokenisation algorithm for Finnish,
+ * this option may be used to tell libvoikko to work around this defect.
+ * Default: false */
+#define VOIKKO_OPT_ACCEPT_MISSING_HYPHENS 12
+
 /* Integer options */
 
 /* There are two possible rules that can be applied when hyphenating compound words
