@@ -21,6 +21,14 @@
 
 #include <stddef.h>
 
+enum char_type {CHAR_UNKNOWN, CHAR_LETTER, CHAR_DIGIT, CHAR_WHITESPACE, CHAR_PUNCTUATION};
+
+/** Returns character type for given character
+ * @param c character to check
+ * @return the character type
+ */
+enum char_type get_char_type(wchar_t c);
+
 /** Normalises an unicode string according to our conventions
  * @param word string to normalise
  * @param len length of the string
@@ -28,4 +36,14 @@
  */
 wchar_t * voikko_normalise(const wchar_t * word, size_t len);
 
+/** Formats modified string to more closely match the original
+ * @param orig original string
+ * @param orig_len length of the original string
+ * @param modified pointer to the modified string. The string may be
+ *        relocated if it needs to be expanded, otherwise it is modified
+ *        in place.
+ * @param modified_len length of the modified string
+ */
+void voikko_cset_reformat(const wchar_t * orig, size_t orig_len, wchar_t ** modified, size_t modified_len);
+
 #endif
